//==========================================================================
// File: traversal.h
// Description: Functions for enumerating vertices, edges, and faces
//   of subdivisions
// Created: Wed Dec  1 18:58:35 EST 1999 by Pat Morin
//==========================================================================
#ifndef __TRAVERSAL_H
#define __TRAVERSAL_H

#include <LEDA/graph.h>
#include <LEDA/point.h>

#include "util.h"

//=======================================================================
// Traverse the subdivision G beginning at the edge estart using de Berg
// et al's constant-additional-memory subdivision traversal algorithm.
//=======================================================================
void bkoo_traversal(const GRAPH<POINT, int> &G, edge estart);

//=======================================================================
// Traverse the subdivision G beginning at the edge estart using de Berg
// et al's constant-additional-memory subdivision traversal algorithm.
//=======================================================================
void bm_traversal(const GRAPH<POINT, int> &G, edge estart);

//=======================================================================
// Traverse the subdivision G beginning at the edge estart using depth
// first search on the faces of G.
//=======================================================================
void dfs_traversal(const GRAPH<POINT, int> &G, edge estart);


// define these if you want to keep stats on the number of comparisons
// performed by bkoo_traversal and bm_traversal
#ifdef MEASURING
extern int bm_cmp_count;
extern int bkoo_cmp_count;
#endif //MEASURING

#endif __TRAVERSAL_H




